@@ -109,6 +109,8 @@ public:
 	static timeout_t exec_timer;
 	static unsigned compile_count;
 	static volatile bool image_loaded;
+	static bool provision_system;
+	static bool provision_user;
 
 	static BayonneDriver *start_driver;
 	static Audio::Encoding peer_encoding;
@@ -181,6 +183,9 @@ public:
 		STATE_READ,
 		STATE_COLLECT,
 		STATE_DIAL,
+		STATE_XFER,
+		STATE_HOLD,
+		STATE_RECALL,
 		STATE_TONE,
 		STATE_PLAY,
 		STATE_RECORD,
@@ -629,6 +634,12 @@ public:
 				timeout_t answer_timer;
 				char digits[64];
 			}	join;
+
+			struct
+			{
+				const char *ref;
+				char buf[MAX_LIST * sizeof(char *)];
+			}	url;
 		};
 		
 	}	State;
@@ -1614,7 +1625,7 @@ protected:
 	uint16 evseq;
 	uint32 tseq;
 	volatile unsigned children;
-	bool offhook, dtmf, answered, starting;
+	bool offhook, dtmf, answered, starting, holding;
 	time_t exittimer, starttime;
 	interface_t iface;
 	bridge_t bridge;
@@ -1677,6 +1688,9 @@ protected:
 	virtual bool enterDial(Event *event);
 	virtual bool enterBusy(Event *event);
 	virtual bool enterStandby(Event *event);
+	virtual bool enterXfer(Event *event);
+	virtual bool enterHold(Event *event);
+	virtual bool enterRecall(Event *event);
 
 	/**
 	 * Check dtmf handling and other nessisities for the interpreter
@@ -1710,6 +1724,9 @@ protected:
 	bool stateInput(Event *event);
 	bool stateRead(Event *event);
 	bool stateDial(Event *event);
+	bool stateXfer(Event *event);
+	bool stateHold(Event *event);
+	bool stateRecall(Event *event);
 	bool stateTone(Event *event);
 	bool statePlay(Event *event);
 	bool stateRecord(Event *event);
