@@ -43,6 +43,8 @@
 #include <cc++/process.h>
 #include <cc++/buffer.h>
 #include <cc++/strchar.h>
+#include <cc++/audio2.h>
+#include <cc++/script3.h>
 //#ifndef	BUILD_LIBEXEC
 #include <cc++/export.h>
 //#endif
