@@ -41,7 +41,7 @@ ScriptInterp(), audio()
 	seq = 0;
 	evseq = 0;
 	tseq = 0;
-	offhook = dtmf = answered = false;
+	offhook = dtmf = answered = holding = false;
 	exittimer = 0;
 	starttime = 0;
 	type = NONE;
@@ -302,6 +302,14 @@ const char *BayonneSession::getExternal(const char *id)
 		id += 8;
 		if(!stricmp(id, "gid") || !stricmp(id, "id") || !stricmp(id, "sid"))
 			return var_sid;
+		else if(!stricmp(id, "line"))
+		{
+			if(holding)
+				return "holding";
+			if(offhook)
+				return "offhook";
+			return "idle";
+		}
 		else if(!stricmp(id, "pid"))
 			return var_pid;
 		else if(!stricmp(id, "callid") || !stricmp(id, "crn"))
@@ -1046,6 +1054,7 @@ void BayonneSession::makeIdle(void)
         type = NONE;
         strcpy(var_rings, "0");
         var_sid[0] = 0;
+	holding = false;
         sym = mapSymbol("session.digits", MAX_DTMF);
         if(sym)
 	{
