@@ -68,7 +68,10 @@ Thread(atoi(getLast("priority")), atoi(getLast("stack")) * 1024)
 	if(env)
 		loadFile(env, "sip");
 #else
-	load("~bayonne/sip");
+	if(Bayonne::provision_system)
+		load("/bayonne/provision/sip");
+	else if(Bayonne::provision_user)
+		load("~bayonne/sip");
 #endif
 	cp = getLast("ack");
 	if(!cp)
