@@ -201,6 +201,19 @@ bool Session::enterTone(Event *event)
 	return false;
 }
 
+bool Session::enterXfer(Event *event)
+{
+	if(event->id == ENTER_STATE)
+	{
+		if(eXosip_transfer_call(did, (char *)state.url.ref))
+		{
+			setState(STATE_HANGUP);
+			return true;
+		}
+	}
+	return false;
+}
+
 void Session::clrAudio(void)
 {
 	if(rtp)
