@@ -90,6 +90,9 @@ static Keydata::Define paths[] = {
 	{"scripts", SCRIPT_FILES},
 	{"macros", MACRO_FILES},
 	{"prompts", PROMPT_FILES},
+#ifndef	WIN32
+	{"btsexec", BIN_FILES "/btsexec"},
+#endif
 	{NULL, NULL}};
 
 static Keydata::Define server[] = {
@@ -378,9 +381,10 @@ void testConfig(char *argv0)
 	keypaths.setValue("modules", "../modules");
 	keypaths.setValue("drivers", "../modules");
 	keypaths.setValue("phrases", "../modules/languages/.libs");
+	keypaths.setValue("btsexec", SOURCE_FILES "/utils/btsexec");
 	keypaths.setValue("prompts", SOURCE_FILES "/audio");
 	keypaths.setValue("scripts", SOURCE_FILES "/scripts");
-	keypaths.setValue("macros", SOURCE_FILES "/macros");
+	keypaths.setValue("macros", SOURCE_FILES "/scripts");
 	keypaths.setValue("config", SOURCE_FILES "/config");
 	keypaths.setValue("datafiles", SOURCE_FILES "/server/tempfiles");
 	keypaths.setValue("logfiles", SOURCE_FILES "/server/tempfiles");
