@@ -127,6 +127,9 @@ bool Methods::scrTransfer(void)
 	const char *cp;
 	const char *pre = getKeyword("prefix");
 
+	if(!pre)
+		pre = driver->getLast("transfer");
+
 	while(NULL != (cp = getValue(NULL)))
 	{
 		snprintf(nbuf + len, sizeof(nbuf) - len, "%s", cp);
@@ -1493,7 +1496,7 @@ finish:
 bool Methods::scrReadpath(void)
 {
 	char fbuf[MAX_PATHNAME];
-	const char *cp = getAudio();
+	const char *cp;
 	Symbol *sym;
 
 	if(cp)
@@ -1516,6 +1519,18 @@ nosym:
 		error("no-symbol");
 		return true;
 	}
+
+	Bayonne::commit(sym, "");
+	cp = getAudio();
+	if(cp)
+	{
+                slog.error("%s: %s", logname, cp);
+                if(!signalScript(SIGNAL_FAIL))
+                        error("invalid-audio");
+		return true;
+	}
+	
+	
 	cp = getValue(NULL);
 	if(!cp || !*cp)
 		goto error;
@@ -1540,17 +1555,9 @@ bool Methods::scrWritepath(void)
 {
 	char buf[MAX_PATHNAME];
 	char fbuf[MAX_PATHNAME];
-	const char *cp = getAudio();
+	const char *cp;
 	Symbol *sym;
 
-	if(cp)
-	{
-                slog.error("%s: %s", logname, cp);
-                if(!signalScript(SIGNAL_FAIL))
-                        error("invalid-audio");
-		return true;
-	}
-
 	cp = getOption(NULL);
 	if(!cp)
 		goto nosym;
@@ -1562,6 +1569,17 @@ nosym:
 		error("no-symbol");
 		return true;
 	}
+
+	Bayonne::commit(sym, "");
+	cp = getAudio();
+	if(cp)
+	{
+                slog.error("%s: %s", logname, cp);
+                if(!signalScript(SIGNAL_FAIL))
+                        error("invalid-audio");
+		return true;
+	}
+	
 	cp = getWritepath(buf, sizeof(buf));
 	if(!cp)
 	{
