@@ -117,6 +117,10 @@ static void loading(void)
 
 	if(!Process::getEnv("SERVER_SYSEXEC"))
 		Process::setEnv("SERVER_SYSEXEC", keypaths.getLast("scripts"), true);
+	
+	cp = keypaths.getLast("btsexec");
+	if(cp && *cp)
+		Process::setEnv("SHELL_BTSEXEC", cp, true);
 
 	Process::setEnv("SERVER_PREFIX", keypaths.getLast("datafiles"), true);
         Process::setEnv("SERVER_PROMPTS", keypaths.getLast("prompts"), true);
